summaryrefslogtreecommitdiff
path: root/src/expr/lazy_proof_chain.cpp
diff options
context:
space:
mode:
authorAndrew Reynolds <andrew.j.reynolds@gmail.com>2021-02-22 16:07:16 -0600
committerGitHub <noreply@github.com>2021-02-22 16:07:16 -0600
commit71d72df0437607723256bbd7b4f28cd6c89fe40f (patch)
tree1021b9e166290db4637a0be447da359d0aed4752 /src/expr/lazy_proof_chain.cpp
parent580f3e93c2cc4564e6fa87d07426dc1ff87224e4 (diff)
(proof-new) Change proof-new option to proof (#5955)
Also moves several proof-specific options to proof_options.
Diffstat (limited to 'src/expr/lazy_proof_chain.cpp')
-rw-r--r--src/expr/lazy_proof_chain.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/expr/lazy_proof_chain.cpp b/src/expr/lazy_proof_chain.cpp
index 665e68d28..2edad1647 100644
--- a/src/expr/lazy_proof_chain.cpp
+++ b/src/expr/lazy_proof_chain.cpp
@@ -17,7 +17,7 @@
#include "expr/proof.h"
#include "expr/proof_ensure_closed.h"
#include "expr/proof_node_algorithm.h"
-#include "options/smt_options.h"
+#include "options/proof_options.h"
namespace CVC4 {
@@ -261,8 +261,8 @@ void LazyCDProofChain::addLazyStep(Node expected,
<< " set to generator " << pg->identify() << "\n";
// note this will rewrite the generator for expected, if any
d_gens.insert(expected, pg);
- // check if chain is closed if options::proofNewEagerChecking() is on
- if (options::proofNewEagerChecking())
+ // check if chain is closed if options::proofEagerChecking() is on
+ if (options::proofEagerChecking())
{
Trace("lazy-cdproofchain")
<< "LazyCDProofChain::addLazyStep: Checking closed proof...\n";
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback